#!/bin/sh

if [ "$1" = "-h" ] ; then
  echo "ebs_snapshot.sh VOLUME_ID SNAPSHOT_GENERATION_NUM SNAPSHOT_DESCRIPTION [aws profile]"
  echo "This script require jq."
fi

CHECK_JQ=`jq -V`
if [ $? -ne 0 ] ; then
  echo "Please install jq."
  exit 1
fi



if [ -z "$1" ] ; then
  echo "Please set volume id at 1st arg."
  exit 1
fi

VOLUME=$1


if [ -z "$2" ] ; then
  echo "Please set generation number at 2nd arg."
  exit 1
fi

GEN_NUM=$2

if [ -z "$3" ] ; then
  echo "Please set snapshot's description at 3rd arg."
  exit 1
fi

DESCRIPTION=$3


PROFILE=""

if [ -n "$4" ] ; then
  PROFILE="--profile $4"
else
  PROFILE="--profile default"
fi

VOLUME=`aws ec2 ${PROFILE} describe-volumes --volume-ids ${VOLUME} --output json | jq -r '.Volumes[].VolumeId'`

if [ -z "${VOLUME}" ] ; then
  echo "This volume not exist."
  exit 1
fi

if [ $? -ne 0 ] ; then
  echo "AWS EC2 describe-volume command failed."
  exit 1
fi


aws ec2 ${PROFILE} create-snapshot --volume-id ${VOLUME} --description "${DESCRIPTION}"

if [ $? -ne 0 ] ; then
  echo "AWS EC2 create-snapshot command failed."
  exit 1
fi


SNAPSHOTS=`aws ec2 ${PROFILE} describe-snapshots --filters Name=volume-id,Values=${VOLUME} --output json | jq -r '.Snapshots|sort_by(.StartTime)|reverse[].SnapshotId'`

if [ $? -ne 0 ] ; then
  echo "AWS EC2 describe-command failed."
  exit 1
fi


COUNT=1
for SNAPSHOT in ${SNAPSHOTS}; do
  if [ ${COUNT} -le ${GEN_NUM} ]; then
    echo "${SNAPSHOT} is kept”
  else
    echo "${SNAPSHOT} is deleted”
    aws ec2 ${PROFILE} delete-snapshot --snapshot-id ${SNAPSHOT}

    if [ $? -ne 0 ] ; then
      echo "AWS EC2 delete-snapshot command failed."
      exit 1
    fi
  fi
  COUNT=`expr ${COUNT} + 1`
done


